@@ -121,7 +121,7 @@ class Columns(JupyterMixin):
         table.title = self.title
 
         if self.width is not None:
-            column_count = max_width // self.width
+            column_count = (max_width) // (self.width + width_padding)
             for _ in range(column_count):
                 table.add_column(width=self.width)
         else:
