@@ -345,10 +345,15 @@ class Style:
         return self._link
 
     @property
-    def transaprent_background(self) -> bool:
+    def transparent_background(self) -> bool:
         """Check if the style specified a transparent background."""
         return self.bgcolor is None or self.bgcolor.is_default
 
+    @property
+    def background_style(self) -> "Style":
+        """A Style with background only."""
+        return Style(bgcolor=self.bgcolor)
+
     @classmethod
     @lru_cache(maxsize=1024)
     def parse(cls, style_definition: str) -> "Style":
@@ -522,6 +527,28 @@ class Style:
         style._null = False
         return style
 
+    def update_link(self, link: str = None) -> "Style":
+        """Get a copy with a different value for link.
+
+        Args:
+            link (str, optional): New value for link. Defaults to None.
+
+        Returns:
+            Style: A new Style instance.
+        """
+        style = self.__new__(Style)
+        style._ansi = self._ansi
+        style._style_definition = self._style_definition
+        style._color = self._color
+        style._bgcolor = self._bgcolor
+        style._attributes = self._attributes
+        style._set_attributes = self._set_attributes
+        style._link = link
+        style._link_id = f"{time()}-{randint(0, 999999)}" if link else ""
+        style._hash = self._hash
+        style._null = False
+        return style
+
     def render(
         self,
         text: str = "",
